Paradise
========

A file sharing and media streaming solution for local networks.

Steps to run:

First install all the requirements

```
pip install -r requirements.txt
```

Run webserver using uvicorn

```
uvicorn server:app --host 0.0.0.0 --port 8000
```
